from buptmw import BUPT_Auth
import requests

data = {
    "username": "2023213685",
    "password": "zero-bupt-A1"
}
BUPT_UCLOUD_CHECK = "https://apiucloud.bupt.edu.cn/blade-portal/home-page-info/getShufflingWebList"

cas = BUPT_Auth(cas=data)
ucloud = cas.get_Ucloud()

resp1 = ucloud.get(BUPT_UCLOUD_CHECK, headers={
    "blade-auth": ucloud.access_token
})
resp2 = requests.get(BUPT_UCLOUD_CHECK, headers={
    "blade-auth": ucloud.access_token
})
pass
