# Session Bases
USER_AGENT = "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.0.0 Safari/537.36"

# CAS
BUPT_CAS_LOGIN = "https://auth.bupt.edu.cn/authserver/login"

# UC
BUPT_UC_LOGIN = "https://uc.bupt.edu.cn/api/login?target=https://uc.bupt.edu.cn/#/user/login"
BUPT_UC_CHECK = "https://uc.bupt.edu.cn/api/uc/status"

# Ucloud
BUPT_UCLOUD_LOGIN = "https://auth.bupt.edu.cn/authserver/login?service=http://ucloud.bupt.edu.cn"
BUPT_UCLOUD_TOKEN = "https://apiucloud.bupt.edu.cn/ykt-basics/oauth/token"
BUPT_UCLOUD_INFO = "https://apiucloud.bupt.edu.cn/ykt-basics/info"
BUPT_UCLOUD_CURRENT = "https://apiucloud.bupt.edu.cn/ykt-site/base-term/current"
BUPT_UCLOUD_USER = "https://apiucloud.bupt.edu.cn/ykt-basics/userroledomaindept/listByUserId"
BUPT_UCLOUD_CHECK = "https://apiucloud.bupt.edu.cn/blade-portal/home-page-info/getShufflingWebList"
